
bottle_compression_zlib_portmonitor plugin
======================================================================
Portmonitor plugin for compression and decompression of bottles (or yarp data types castable to bottle) using zlib library.

Usage:
-----

yarp connect /src /dest tcp+send.portmonitor+file.bottle_compression_zlib+recv.portmonitor+file.bottle_compression_zlib+type.dll
